# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class SpbmNodeIsIdRange(Base):
	"""The SpbmNodeIsIdRange class encapsulates a user managed spbmNodeIsIdRange node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the SpbmNodeIsIdRange property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'spbmNodeIsIdRange'

	def __init__(self, parent):
		super(SpbmNodeIsIdRange, self).__init__(parent)

	@property
	def CMacAddressCount(self):
		"""The number of C-MAC addresses.

		Returns:
			number
		"""
		return self._get_attribute('cMacAddressCount')
	@CMacAddressCount.setter
	def CMacAddressCount(self, value):
		self._set_attribute('cMacAddressCount', value)

	@property
	def CMacAddressStep(self):
		"""The incremental value of C-MAC address.

		Returns:
			str
		"""
		return self._get_attribute('cMacAddressStep')
	@CMacAddressStep.setter
	def CMacAddressStep(self, value):
		self._set_attribute('cMacAddressStep', value)

	@property
	def ITagEthernetType(self):
		"""The I-Tag Ethernet type. An I-Tag is a multiplexing tag for service instance scaling in Provider Bridged Networks.

		Returns:
			number
		"""
		return self._get_attribute('iTagEthernetType')

	@property
	def InterNodeCmacAddress(self):
		"""The incremental value of the Inter Node C-MAC address.

		Returns:
			str
		"""
		return self._get_attribute('interNodeCmacAddress')
	@InterNodeCmacAddress.setter
	def InterNodeCmacAddress(self, value):
		self._set_attribute('interNodeCmacAddress', value)

	@property
	def InterNodeCvlan(self):
		"""The Inter Node Stacked VLAN.

		Returns:
			number
		"""
		return self._get_attribute('interNodeCvlan')
	@InterNodeCvlan.setter
	def InterNodeCvlan(self, value):
		self._set_attribute('interNodeCvlan', value)

	@property
	def InterNodeIsIdIncrement(self):
		"""The incremental value of Inter Node service identifier.

		Returns:
			number
		"""
		return self._get_attribute('interNodeIsIdIncrement')
	@InterNodeIsIdIncrement.setter
	def InterNodeIsIdIncrement(self, value):
		self._set_attribute('interNodeIsIdIncrement', value)

	@property
	def InterNodeSvlan(self):
		"""The Inter Node Single VLAN.

		Returns:
			number
		"""
		return self._get_attribute('interNodeSvlan')
	@InterNodeSvlan.setter
	def InterNodeSvlan(self, value):
		self._set_attribute('interNodeSvlan', value)

	@property
	def IsId(self):
		"""The I-component service identifier. The maximum value is 16777215. The minimum value is 0.

		Returns:
			number
		"""
		return self._get_attribute('isId')
	@IsId.setter
	def IsId(self, value):
		self._set_attribute('isId', value)

	@property
	def RBit(self):
		"""The Restart State bit.

		Returns:
			bool
		"""
		return self._get_attribute('rBit')
	@RBit.setter
	def RBit(self, value):
		self._set_attribute('rBit', value)

	@property
	def StartCmacAddress(self):
		"""The starting C-MAC address.

		Returns:
			str
		"""
		return self._get_attribute('startCmacAddress')
	@StartCmacAddress.setter
	def StartCmacAddress(self, value):
		self._set_attribute('startCmacAddress', value)

	@property
	def StartCvlan(self):
		"""The starting value of Stacked VLAN.

		Returns:
			number
		"""
		return self._get_attribute('startCvlan')
	@StartCvlan.setter
	def StartCvlan(self, value):
		self._set_attribute('startCvlan', value)

	@property
	def StartSvlan(self):
		"""The starting value of Single VLAN.

		Returns:
			number
		"""
		return self._get_attribute('startSvlan')
	@StartSvlan.setter
	def StartSvlan(self, value):
		self._set_attribute('startSvlan', value)

	@property
	def TBit(self):
		"""The external route tag bit.

		Returns:
			bool
		"""
		return self._get_attribute('tBit')
	@TBit.setter
	def TBit(self, value):
		self._set_attribute('tBit', value)

	@property
	def TrafficDestMacAddress(self):
		"""The traffic-destination MAC address.

		Returns:
			str
		"""
		return self._get_attribute('trafficDestMacAddress')
	@TrafficDestMacAddress.setter
	def TrafficDestMacAddress(self, value):
		self._set_attribute('trafficDestMacAddress', value)

	@property
	def TransmissionType(self):
		"""Select the type of packet transmission. Options include Unicast and Multicast.

		Returns:
			number
		"""
		return self._get_attribute('transmissionType')
	@TransmissionType.setter
	def TransmissionType(self, value):
		self._set_attribute('transmissionType', value)

	@property
	def VlanType(self):
		"""The type of VLAN.

		Returns:
			number
		"""
		return self._get_attribute('vlanType')
	@VlanType.setter
	def VlanType(self, value):
		self._set_attribute('vlanType', value)

	def update(self, CMacAddressCount=None, CMacAddressStep=None, InterNodeCmacAddress=None, InterNodeCvlan=None, InterNodeIsIdIncrement=None, InterNodeSvlan=None, IsId=None, RBit=None, StartCmacAddress=None, StartCvlan=None, StartSvlan=None, TBit=None, TrafficDestMacAddress=None, TransmissionType=None, VlanType=None):
		"""Updates a child instance of spbmNodeIsIdRange on the server.

		Args:
			CMacAddressCount (number): The number of C-MAC addresses.
			CMacAddressStep (str): The incremental value of C-MAC address.
			InterNodeCmacAddress (str): The incremental value of the Inter Node C-MAC address.
			InterNodeCvlan (number): The Inter Node Stacked VLAN.
			InterNodeIsIdIncrement (number): The incremental value of Inter Node service identifier.
			InterNodeSvlan (number): The Inter Node Single VLAN.
			IsId (number): The I-component service identifier. The maximum value is 16777215. The minimum value is 0.
			RBit (bool): The Restart State bit.
			StartCmacAddress (str): The starting C-MAC address.
			StartCvlan (number): The starting value of Stacked VLAN.
			StartSvlan (number): The starting value of Single VLAN.
			TBit (bool): The external route tag bit.
			TrafficDestMacAddress (str): The traffic-destination MAC address.
			TransmissionType (number): Select the type of packet transmission. Options include Unicast and Multicast.
			VlanType (number): The type of VLAN.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, CMacAddressCount=None, CMacAddressStep=None, InterNodeCmacAddress=None, InterNodeCvlan=None, InterNodeIsIdIncrement=None, InterNodeSvlan=None, IsId=None, RBit=None, StartCmacAddress=None, StartCvlan=None, StartSvlan=None, TBit=None, TrafficDestMacAddress=None, TransmissionType=None, VlanType=None):
		"""Adds a new spbmNodeIsIdRange node on the server and retrieves it in this instance.

		Args:
			CMacAddressCount (number): The number of C-MAC addresses.
			CMacAddressStep (str): The incremental value of C-MAC address.
			InterNodeCmacAddress (str): The incremental value of the Inter Node C-MAC address.
			InterNodeCvlan (number): The Inter Node Stacked VLAN.
			InterNodeIsIdIncrement (number): The incremental value of Inter Node service identifier.
			InterNodeSvlan (number): The Inter Node Single VLAN.
			IsId (number): The I-component service identifier. The maximum value is 16777215. The minimum value is 0.
			RBit (bool): The Restart State bit.
			StartCmacAddress (str): The starting C-MAC address.
			StartCvlan (number): The starting value of Stacked VLAN.
			StartSvlan (number): The starting value of Single VLAN.
			TBit (bool): The external route tag bit.
			TrafficDestMacAddress (str): The traffic-destination MAC address.
			TransmissionType (number): Select the type of packet transmission. Options include Unicast and Multicast.
			VlanType (number): The type of VLAN.

		Returns:
			self: This instance with all currently retrieved spbmNodeIsIdRange data using find and the newly added spbmNodeIsIdRange data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the spbmNodeIsIdRange data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, CMacAddressCount=None, CMacAddressStep=None, ITagEthernetType=None, InterNodeCmacAddress=None, InterNodeCvlan=None, InterNodeIsIdIncrement=None, InterNodeSvlan=None, IsId=None, RBit=None, StartCmacAddress=None, StartCvlan=None, StartSvlan=None, TBit=None, TrafficDestMacAddress=None, TransmissionType=None, VlanType=None):
		"""Finds and retrieves spbmNodeIsIdRange data from the server.

		All named parameters support regex and can be used to selectively retrieve spbmNodeIsIdRange data from the server.
		By default the find method takes no parameters and will retrieve all spbmNodeIsIdRange data from the server.

		Args:
			CMacAddressCount (number): The number of C-MAC addresses.
			CMacAddressStep (str): The incremental value of C-MAC address.
			ITagEthernetType (number): The I-Tag Ethernet type. An I-Tag is a multiplexing tag for service instance scaling in Provider Bridged Networks.
			InterNodeCmacAddress (str): The incremental value of the Inter Node C-MAC address.
			InterNodeCvlan (number): The Inter Node Stacked VLAN.
			InterNodeIsIdIncrement (number): The incremental value of Inter Node service identifier.
			InterNodeSvlan (number): The Inter Node Single VLAN.
			IsId (number): The I-component service identifier. The maximum value is 16777215. The minimum value is 0.
			RBit (bool): The Restart State bit.
			StartCmacAddress (str): The starting C-MAC address.
			StartCvlan (number): The starting value of Stacked VLAN.
			StartSvlan (number): The starting value of Single VLAN.
			TBit (bool): The external route tag bit.
			TrafficDestMacAddress (str): The traffic-destination MAC address.
			TransmissionType (number): Select the type of packet transmission. Options include Unicast and Multicast.
			VlanType (number): The type of VLAN.

		Returns:
			self: This instance with matching spbmNodeIsIdRange data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of spbmNodeIsIdRange data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the spbmNodeIsIdRange data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class Statistics(Base):
	"""The Statistics class encapsulates a required statistics node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the Statistics property from a parent instance.
	The internal properties list will contain one and only one set of properties which is populated when the property is accessed.
	"""

	_SDM_NAME = 'statistics'

	def __init__(self, parent):
		super(Statistics, self).__init__(parent)

	@property
	def AdvancedSequenceChecking(self):
		"""An instance of the AdvancedSequenceChecking class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.statistics.advancedsequencechecking.advancedsequencechecking.AdvancedSequenceChecking)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.statistics.advancedsequencechecking.advancedsequencechecking import AdvancedSequenceChecking
		return AdvancedSequenceChecking(self)._select()

	@property
	def CpdpConvergence(self):
		"""An instance of the CpdpConvergence class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.statistics.cpdpconvergence.cpdpconvergence.CpdpConvergence)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.statistics.cpdpconvergence.cpdpconvergence import CpdpConvergence
		return CpdpConvergence(self)._select()

	@property
	def DataIntegrity(self):
		"""An instance of the DataIntegrity class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.statistics.dataintegrity.dataintegrity.DataIntegrity)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.statistics.dataintegrity.dataintegrity import DataIntegrity
		return DataIntegrity(self)._select()

	@property
	def DelayVariation(self):
		"""An instance of the DelayVariation class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.statistics.delayvariation.delayvariation.DelayVariation)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.statistics.delayvariation.delayvariation import DelayVariation
		return DelayVariation(self)._select()

	@property
	def ErrorStats(self):
		"""An instance of the ErrorStats class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.statistics.errorstats.errorstats.ErrorStats)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.statistics.errorstats.errorstats import ErrorStats
		return ErrorStats(self)._select()

	@property
	def InterArrivalTimeRate(self):
		"""An instance of the InterArrivalTimeRate class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.statistics.interarrivaltimerate.interarrivaltimerate.InterArrivalTimeRate)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.statistics.interarrivaltimerate.interarrivaltimerate import InterArrivalTimeRate
		return InterArrivalTimeRate(self)._select()

	@property
	def Iptv(self):
		"""An instance of the Iptv class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.statistics.iptv.iptv.Iptv)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.statistics.iptv.iptv import Iptv
		return Iptv(self)._select()

	@property
	def L1Rates(self):
		"""An instance of the L1Rates class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.statistics.l1rates.l1rates.L1Rates)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.statistics.l1rates.l1rates import L1Rates
		return L1Rates(self)._select()

	@property
	def Latency(self):
		"""An instance of the Latency class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.statistics.latency.latency.Latency)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.statistics.latency.latency import Latency
		return Latency(self)._select()

	@property
	def MisdirectedPerFlow(self):
		"""An instance of the MisdirectedPerFlow class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.statistics.misdirectedperflow.misdirectedperflow.MisdirectedPerFlow)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.statistics.misdirectedperflow.misdirectedperflow import MisdirectedPerFlow
		return MisdirectedPerFlow(self)._select()

	@property
	def MultipleJoinLeaveLatency(self):
		"""An instance of the MultipleJoinLeaveLatency class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.statistics.multiplejoinleavelatency.multiplejoinleavelatency.MultipleJoinLeaveLatency)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.statistics.multiplejoinleavelatency.multiplejoinleavelatency import MultipleJoinLeaveLatency
		return MultipleJoinLeaveLatency(self)._select()

	@property
	def OneTimeJoinLeaveLatency(self):
		"""An instance of the OneTimeJoinLeaveLatency class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.statistics.onetimejoinleavelatency.onetimejoinleavelatency.OneTimeJoinLeaveLatency)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.statistics.onetimejoinleavelatency.onetimejoinleavelatency import OneTimeJoinLeaveLatency
		return OneTimeJoinLeaveLatency(self)._select()

	@property
	def PacketLossDuration(self):
		"""An instance of the PacketLossDuration class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.statistics.packetlossduration.packetlossduration.PacketLossDuration)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.statistics.packetlossduration.packetlossduration import PacketLossDuration
		return PacketLossDuration(self)._select()

	@property
	def Prbs(self):
		"""An instance of the Prbs class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.statistics.prbs.prbs.Prbs)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.statistics.prbs.prbs import Prbs
		return Prbs(self)._select()

	@property
	def SequenceChecking(self):
		"""An instance of the SequenceChecking class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.statistics.sequencechecking.sequencechecking.SequenceChecking)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.traffic.statistics.sequencechecking.sequencechecking import SequenceChecking
		return SequenceChecking(self)._select()



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class Layer23NextGenProtocolFilter(Base):
	"""The Layer23NextGenProtocolFilter class encapsulates a user managed layer23NextGenProtocolFilter node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the Layer23NextGenProtocolFilter property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'layer23NextGenProtocolFilter'

	def __init__(self, parent):
		super(Layer23NextGenProtocolFilter, self).__init__(parent)

	@property
	def AdvancedFilter(self):
		"""An instance of the AdvancedFilter class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.statistics.view.layer23nextgenprotocolfilter.advancedfilter.advancedfilter.AdvancedFilter)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.statistics.view.layer23nextgenprotocolfilter.advancedfilter.advancedfilter import AdvancedFilter
		return AdvancedFilter(self)

	@property
	def AvailableAdvancedFilterOptions(self):
		"""An instance of the AvailableAdvancedFilterOptions class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.statistics.view.layer23nextgenprotocolfilter.availableadvancedfilteroptions.availableadvancedfilteroptions.AvailableAdvancedFilterOptions)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.statistics.view.layer23nextgenprotocolfilter.availableadvancedfilteroptions.availableadvancedfilteroptions import AvailableAdvancedFilterOptions
		return AvailableAdvancedFilterOptions(self)

	@property
	def AdvancedCVFilter(self):
		"""Sets the advanced filter for a custom view. Note: To change the filter on an existing view, you must first disable it.

		Returns:
			str(None|/api/v1/sessions/1/ixnetwork/statistics?deepchild=advancedCVFilters)
		"""
		return self._get_attribute('advancedCVFilter')
	@AdvancedCVFilter.setter
	def AdvancedCVFilter(self, value):
		self._set_attribute('advancedCVFilter', value)

	@property
	def AdvancedFilterName(self):
		"""Selects an advanced filter from the ones available in the selected drill down view.

		Returns:
			str
		"""
		return self._get_attribute('advancedFilterName')
	@AdvancedFilterName.setter
	def AdvancedFilterName(self, value):
		self._set_attribute('advancedFilterName', value)

	@property
	def AggregationType(self):
		"""Signifies the type of aggregation of next gen protocols

		Returns:
			str(perPort|perSession)
		"""
		return self._get_attribute('aggregationType')
	@AggregationType.setter
	def AggregationType(self, value):
		self._set_attribute('aggregationType', value)

	@property
	def AllAdvancedFilters(self):
		"""Returns a list with all the filters that are present in the selected drill down views. This includes filters that cannot be applied for the current drill down view.

		Returns:
			str(None|/api/v1/sessions/1/ixnetwork/statistics?deepchild=availableAdvancedFilters)
		"""
		return self._get_attribute('allAdvancedFilters')

	@property
	def MatchingAdvancedFilters(self):
		"""Returns a list that contains only the filters that can be applied on the current drill down view.

		Returns:
			str(None|/api/v1/sessions/1/ixnetwork/statistics?deepchild=availableAdvancedFilters)
		"""
		return self._get_attribute('matchingAdvancedFilters')

	@property
	def PortFilterIds(self):
		"""Filters the port IDs

		Returns:
			list(str[None|/api/v1/sessions/1/ixnetwork/statistics?deepchild=availablePortFilter])
		"""
		return self._get_attribute('portFilterIds')
	@PortFilterIds.setter
	def PortFilterIds(self, value):
		self._set_attribute('portFilterIds', value)

	@property
	def ProtocolFilterIds(self):
		"""Filters the protocol IDs

		Returns:
			list(str[None|/api/v1/sessions/1/ixnetwork/statistics?deepchild=availableProtocolFilter])
		"""
		return self._get_attribute('protocolFilterIds')
	@ProtocolFilterIds.setter
	def ProtocolFilterIds(self, value):
		self._set_attribute('protocolFilterIds', value)

	def update(self, AdvancedCVFilter=None, AdvancedFilterName=None, AggregationType=None, PortFilterIds=None, ProtocolFilterIds=None):
		"""Updates a child instance of layer23NextGenProtocolFilter on the server.

		Args:
			AdvancedCVFilter (str(None|/api/v1/sessions/1/ixnetwork/statistics?deepchild=advancedCVFilters)): Sets the advanced filter for a custom view. Note: To change the filter on an existing view, you must first disable it.
			AdvancedFilterName (str): Selects an advanced filter from the ones available in the selected drill down view.
			AggregationType (str(perPort|perSession)): Signifies the type of aggregation of next gen protocols
			PortFilterIds (list(str[None|/api/v1/sessions/1/ixnetwork/statistics?deepchild=availablePortFilter])): Filters the port IDs
			ProtocolFilterIds (list(str[None|/api/v1/sessions/1/ixnetwork/statistics?deepchild=availableProtocolFilter])): Filters the protocol IDs

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, AdvancedCVFilter=None, AdvancedFilterName=None, AggregationType=None, PortFilterIds=None, ProtocolFilterIds=None):
		"""Adds a new layer23NextGenProtocolFilter node on the server and retrieves it in this instance.

		Args:
			AdvancedCVFilter (str(None|/api/v1/sessions/1/ixnetwork/statistics?deepchild=advancedCVFilters)): Sets the advanced filter for a custom view. Note: To change the filter on an existing view, you must first disable it.
			AdvancedFilterName (str): Selects an advanced filter from the ones available in the selected drill down view.
			AggregationType (str(perPort|perSession)): Signifies the type of aggregation of next gen protocols
			PortFilterIds (list(str[None|/api/v1/sessions/1/ixnetwork/statistics?deepchild=availablePortFilter])): Filters the port IDs
			ProtocolFilterIds (list(str[None|/api/v1/sessions/1/ixnetwork/statistics?deepchild=availableProtocolFilter])): Filters the protocol IDs

		Returns:
			self: This instance with all currently retrieved layer23NextGenProtocolFilter data using find and the newly added layer23NextGenProtocolFilter data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the layer23NextGenProtocolFilter data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, AdvancedCVFilter=None, AdvancedFilterName=None, AggregationType=None, AllAdvancedFilters=None, MatchingAdvancedFilters=None, PortFilterIds=None, ProtocolFilterIds=None):
		"""Finds and retrieves layer23NextGenProtocolFilter data from the server.

		All named parameters support regex and can be used to selectively retrieve layer23NextGenProtocolFilter data from the server.
		By default the find method takes no parameters and will retrieve all layer23NextGenProtocolFilter data from the server.

		Args:
			AdvancedCVFilter (str(None|/api/v1/sessions/1/ixnetwork/statistics?deepchild=advancedCVFilters)): Sets the advanced filter for a custom view. Note: To change the filter on an existing view, you must first disable it.
			AdvancedFilterName (str): Selects an advanced filter from the ones available in the selected drill down view.
			AggregationType (str(perPort|perSession)): Signifies the type of aggregation of next gen protocols
			AllAdvancedFilters (str(None|/api/v1/sessions/1/ixnetwork/statistics?deepchild=availableAdvancedFilters)): Returns a list with all the filters that are present in the selected drill down views. This includes filters that cannot be applied for the current drill down view.
			MatchingAdvancedFilters (str(None|/api/v1/sessions/1/ixnetwork/statistics?deepchild=availableAdvancedFilters)): Returns a list that contains only the filters that can be applied on the current drill down view.
			PortFilterIds (list(str[None|/api/v1/sessions/1/ixnetwork/statistics?deepchild=availablePortFilter])): Filters the port IDs
			ProtocolFilterIds (list(str[None|/api/v1/sessions/1/ixnetwork/statistics?deepchild=availableProtocolFilter])): Filters the protocol IDs

		Returns:
			self: This instance with matching layer23NextGenProtocolFilter data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of layer23NextGenProtocolFilter data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the layer23NextGenProtocolFilter data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)

	def AddAdvancedFilter(self, *args, **kwargs):
		"""Executes the addAdvancedFilter operation on the server.

		NOT DEFINED

		addAdvancedFilter(Arg2:href)
			Args:
				args[0] is Arg2 (str(None|/api/v1/sessions/1/ixnetwork/statistics?deepchild=availableAdvancedFilters)): NOT DEFINED

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('addAdvancedFilter', payload=payload, response_object=None)

	def RemoveAdvancedFilter(self, *args, **kwargs):
		"""Executes the removeAdvancedFilter operation on the server.

		NOT DEFINED

		removeAdvancedFilter(Arg2:string)
			Args:
				args[0] is Arg2 (str): NOT DEFINED

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('removeAdvancedFilter', payload=payload, response_object=None)

	def RemoveAllAdvancedFilters(self):
		"""Executes the removeAllAdvancedFilters operation on the server.

		NOT DEFINED

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('removeAllAdvancedFilters', payload=payload, response_object=None)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class TestConfig(Base):
	"""The TestConfig class encapsulates a required testConfig node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the TestConfig property from a parent instance.
	The internal properties list will contain one and only one set of properties which is populated when the property is accessed.
	"""

	_SDM_NAME = 'testConfig'

	def __init__(self, parent):
		super(TestConfig, self).__init__(parent)

	@property
	def AlgorithmType(self):
		"""The type of algorithm used.

		Returns:
			str(srvConfiguration|srvPerformance)
		"""
		return self._get_attribute('algorithmType')
	@AlgorithmType.setter
	def AlgorithmType(self, value):
		self._set_attribute('algorithmType', value)

	@property
	def CalculateJitter(self):
		"""Calculates the interval between timestamps of PGID packet arrivals.

		Returns:
			bool
		"""
		return self._get_attribute('calculateJitter')
	@CalculateJitter.setter
	def CalculateJitter(self, value):
		self._set_attribute('calculateJitter', value)

	@property
	def CalculateLatency(self):
		"""Calculates and reports latency.

		Returns:
			bool
		"""
		return self._get_attribute('calculateLatency')
	@CalculateLatency.setter
	def CalculateLatency(self, value):
		self._set_attribute('calculateLatency', value)

	@property
	def ContinuePassFailed(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('continuePassFailed')
	@ContinuePassFailed.setter
	def ContinuePassFailed(self, value):
		self._set_attribute('continuePassFailed', value)

	@property
	def CurrentService(self):
		"""The service in use currently.

		Returns:
			str
		"""
		return self._get_attribute('currentService')
	@CurrentService.setter
	def CurrentService(self, value):
		self._set_attribute('currentService', value)

	@property
	def DelayAfterTransmit(self):
		"""Specifies the amount of delay after every transmit.

		Returns:
			number
		"""
		return self._get_attribute('delayAfterTransmit')
	@DelayAfterTransmit.setter
	def DelayAfterTransmit(self, value):
		self._set_attribute('delayAfterTransmit', value)

	@property
	def Duration(self):
		"""The duration of the test in hours, which is used to calculate the number of frames to transmit.

		Returns:
			number
		"""
		return self._get_attribute('duration')
	@Duration.setter
	def Duration(self, value):
		self._set_attribute('duration', value)

	@property
	def DurationLabel(self):
		"""The label defining the traffic duration time.

		Returns:
			str
		"""
		return self._get_attribute('durationLabel')
	@DurationLabel.setter
	def DurationLabel(self, value):
		self._set_attribute('durationLabel', value)

	@property
	def EnableBurstTest(self):
		"""If true, enables burst test.

		Returns:
			bool
		"""
		return self._get_attribute('enableBurstTest')
	@EnableBurstTest.setter
	def EnableBurstTest(self, value):
		self._set_attribute('enableBurstTest', value)

	@property
	def EnableDataIntegrity(self):
		"""If true, enables data integrity test.

		Returns:
			bool
		"""
		return self._get_attribute('enableDataIntegrity')
	@EnableDataIntegrity.setter
	def EnableDataIntegrity(self, value):
		self._set_attribute('enableDataIntegrity', value)

	@property
	def EnableLatencyPassFailLabel(self):
		"""The latency pass fail criteria is set.

		Returns:
			str
		"""
		return self._get_attribute('enableLatencyPassFailLabel')
	@EnableLatencyPassFailLabel.setter
	def EnableLatencyPassFailLabel(self, value):
		self._set_attribute('enableLatencyPassFailLabel', value)

	@property
	def EnableLayer1Rate(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('enableLayer1Rate')
	@EnableLayer1Rate.setter
	def EnableLayer1Rate(self, value):
		self._set_attribute('enableLayer1Rate', value)

	@property
	def EnableStandardDeviationPassFailLabel(self):
		"""Standard Deviation for the Pass/Fail criteria is set.

		Returns:
			str
		"""
		return self._get_attribute('enableStandardDeviationPassFailLabel')
	@EnableStandardDeviationPassFailLabel.setter
	def EnableStandardDeviationPassFailLabel(self, value):
		self._set_attribute('enableStandardDeviationPassFailLabel', value)

	@property
	def ForceRegenerate(self):
		"""Initiates a forced regeneration.

		Returns:
			bool
		"""
		return self._get_attribute('forceRegenerate')
	@ForceRegenerate.setter
	def ForceRegenerate(self, value):
		self._set_attribute('forceRegenerate', value)

	@property
	def FrameDataDetailedResults(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('frameDataDetailedResults')
	@FrameDataDetailedResults.setter
	def FrameDataDetailedResults(self, value):
		self._set_attribute('frameDataDetailedResults', value)

	@property
	def FrameLossFramesMode(self):
		"""NOT DEFINED

		Returns:
			str
		"""
		return self._get_attribute('frameLossFramesMode')
	@FrameLossFramesMode.setter
	def FrameLossFramesMode(self, value):
		self._set_attribute('frameLossFramesMode', value)

	@property
	def FrameSizeMode(self):
		"""This attribute is the frame size mode for the Quad Gaussian.

		Returns:
			str(custom|customlist|increment|random)
		"""
		return self._get_attribute('frameSizeMode')
	@FrameSizeMode.setter
	def FrameSizeMode(self, value):
		self._set_attribute('frameSizeMode', value)

	@property
	def Gap(self):
		"""The gap in transmission of frames.

		Returns:
			number
		"""
		return self._get_attribute('gap')
	@Gap.setter
	def Gap(self, value):
		self._set_attribute('gap', value)

	@property
	def GenerateTrackingOptionAggregationFiles(self):
		"""If true, enables the tracking option in aggregation files.

		Returns:
			bool
		"""
		return self._get_attribute('generateTrackingOptionAggregationFiles')
	@GenerateTrackingOptionAggregationFiles.setter
	def GenerateTrackingOptionAggregationFiles(self, value):
		self._set_attribute('generateTrackingOptionAggregationFiles', value)

	@property
	def IsColorAware(self):
		"""If true, it becomes aware of the color.

		Returns:
			bool
		"""
		return self._get_attribute('isColorAware')
	@IsColorAware.setter
	def IsColorAware(self, value):
		self._set_attribute('isColorAware', value)

	@property
	def IsServicePeformanceMode(self):
		"""The service performance mode.

		Returns:
			str
		"""
		return self._get_attribute('isServicePeformanceMode')
	@IsServicePeformanceMode.setter
	def IsServicePeformanceMode(self, value):
		self._set_attribute('isServicePeformanceMode', value)

	@property
	def IterationInitialRate(self):
		"""The initial rate of iteration.

		Returns:
			str
		"""
		return self._get_attribute('iterationInitialRate')
	@IterationInitialRate.setter
	def IterationInitialRate(self, value):
		self._set_attribute('iterationInitialRate', value)

	@property
	def IterationStep(self):
		"""The iteration step.

		Returns:
			str
		"""
		return self._get_attribute('iterationStep')
	@IterationStep.setter
	def IterationStep(self, value):
		self._set_attribute('iterationStep', value)

	@property
	def LatencyBins(self):
		"""DEPRECATED Sets the latency bins statistics.

		Returns:
			str
		"""
		return self._get_attribute('latencyBins')
	@LatencyBins.setter
	def LatencyBins(self, value):
		self._set_attribute('latencyBins', value)

	@property
	def LatencyBinsEnabled(self):
		"""DEPRECATED Enables the latency bins statistics.

		Returns:
			bool
		"""
		return self._get_attribute('latencyBinsEnabled')
	@LatencyBinsEnabled.setter
	def LatencyBinsEnabled(self, value):
		self._set_attribute('latencyBinsEnabled', value)

	@property
	def LatencyType(self):
		"""DEPRECATED The type of latency.

		Returns:
			str(cutThrough|mef|storeForward)
		"""
		return self._get_attribute('latencyType')
	@LatencyType.setter
	def LatencyType(self, value):
		self._set_attribute('latencyType', value)

	@property
	def LearnSnoopConfig(self):
		"""DEPRECATED The learned snoop configuration.

		Returns:
			bool
		"""
		return self._get_attribute('learnSnoopConfig')
	@LearnSnoopConfig.setter
	def LearnSnoopConfig(self, value):
		self._set_attribute('learnSnoopConfig', value)

	@property
	def NoOfFrames(self):
		"""DEPRECATED The number of frames sent.

		Returns:
			str
		"""
		return self._get_attribute('noOfFrames')
	@NoOfFrames.setter
	def NoOfFrames(self, value):
		self._set_attribute('noOfFrames', value)

	@property
	def Numtrials(self):
		"""DEPRECATED This signifies the Number of trials.

		Returns:
			number
		"""
		return self._get_attribute('numtrials')
	@Numtrials.setter
	def Numtrials(self, value):
		self._set_attribute('numtrials', value)

	@property
	def PortDelayEnabled(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('portDelayEnabled')
	@PortDelayEnabled.setter
	def PortDelayEnabled(self, value):
		self._set_attribute('portDelayEnabled', value)

	@property
	def PortDelayUnit(self):
		"""DEPRECATED Sets the port delay unit in which it will be measured.

		Returns:
			str(bytes|nanoseconds)
		"""
		return self._get_attribute('portDelayUnit')
	@PortDelayUnit.setter
	def PortDelayUnit(self, value):
		self._set_attribute('portDelayUnit', value)

	@property
	def PortDelayValue(self):
		"""DEPRECATED Sets the port delay value.

		Returns:
			number
		"""
		return self._get_attribute('portDelayValue')
	@PortDelayValue.setter
	def PortDelayValue(self, value):
		self._set_attribute('portDelayValue', value)

	@property
	def ProtocolItem(self):
		"""DEPRECATED Protocol Items

		Returns:
			list(str[None|/api/v1/sessions/1/ixnetwork/vport|/api/v1/sessions/1/ixnetwork/vport?deepchild=lan])
		"""
		return self._get_attribute('protocolItem')
	@ProtocolItem.setter
	def ProtocolItem(self, value):
		self._set_attribute('protocolItem', value)

	@property
	def ReportSequenceError(self):
		"""DEPRECATED If true, the sequence error, if found, is reported.

		Returns:
			bool
		"""
		return self._get_attribute('reportSequenceError')
	@ReportSequenceError.setter
	def ReportSequenceError(self, value):
		self._set_attribute('reportSequenceError', value)

	@property
	def ReportTputRateUnit(self):
		"""DEPRECATED The unit of rate for throughput.

		Returns:
			str(gbps|gBps|kbps|kBps|mbps|mBps)
		"""
		return self._get_attribute('reportTputRateUnit')
	@ReportTputRateUnit.setter
	def ReportTputRateUnit(self, value):
		self._set_attribute('reportTputRateUnit', value)

	@property
	def Rfc2889ordering(self):
		"""DEPRECATED NOT DEFINED

		Returns:
			str(noOrdering|unchanged|val2889Ordering)
		"""
		return self._get_attribute('rfc2889ordering')
	@Rfc2889ordering.setter
	def Rfc2889ordering(self, value):
		self._set_attribute('rfc2889ordering', value)

	@property
	def ServiceIterations(self):
		"""DEPRECATED Number of service iterations.

		Returns:
			str
		"""
		return self._get_attribute('serviceIterations')
	@ServiceIterations.setter
	def ServiceIterations(self, value):
		self._set_attribute('serviceIterations', value)

	@property
	def ServicesList(self):
		"""DEPRECATED The list of service.

		Returns:
			str
		"""
		return self._get_attribute('servicesList')
	@ServicesList.setter
	def ServicesList(self, value):
		self._set_attribute('servicesList', value)

	@property
	def SkipDefaultPassFailEvaluation(self):
		"""DEPRECATED If true, it skips the default pass fail evaluation.

		Returns:
			bool
		"""
		return self._get_attribute('skipDefaultPassFailEvaluation')
	@SkipDefaultPassFailEvaluation.setter
	def SkipDefaultPassFailEvaluation(self, value):
		self._set_attribute('skipDefaultPassFailEvaluation', value)

	@property
	def StaggeredStart(self):
		"""DEPRECATED Staggered start of traffic.

		Returns:
			bool
		"""
		return self._get_attribute('staggeredStart')
	@StaggeredStart.setter
	def StaggeredStart(self, value):
		self._set_attribute('staggeredStart', value)

	@property
	def TestTrafficType(self):
		"""DEPRECATED It gives the test traffic type.

		Returns:
			str
		"""
		return self._get_attribute('testTrafficType')
	@TestTrafficType.setter
	def TestTrafficType(self, value):
		self._set_attribute('testTrafficType', value)

	@property
	def TransmitMode(self):
		"""DEPRECATED The transmit mode for this traffic item.

		Returns:
			str(noFrames|useDuration)
		"""
		return self._get_attribute('transmitMode')
	@TransmitMode.setter
	def TransmitMode(self, value):
		self._set_attribute('transmitMode', value)

	@property
	def TxDelay(self):
		"""DEPRECATED The minimum delay between successive packets.

		Returns:
			number
		"""
		return self._get_attribute('txDelay')
	@TxDelay.setter
	def TxDelay(self, value):
		self._set_attribute('txDelay', value)

	def update(self, AlgorithmType=None, CalculateJitter=None, CalculateLatency=None, ContinuePassFailed=None, CurrentService=None, DelayAfterTransmit=None, Duration=None, DurationLabel=None, EnableBurstTest=None, EnableDataIntegrity=None, EnableLatencyPassFailLabel=None, EnableLayer1Rate=None, EnableStandardDeviationPassFailLabel=None, ForceRegenerate=None, FrameDataDetailedResults=None, FrameLossFramesMode=None, FrameSizeMode=None, Gap=None, GenerateTrackingOptionAggregationFiles=None, IsColorAware=None, IsServicePeformanceMode=None, IterationInitialRate=None, IterationStep=None, LatencyBins=None, LatencyBinsEnabled=None, LatencyType=None, LearnSnoopConfig=None, NoOfFrames=None, Numtrials=None, PortDelayEnabled=None, PortDelayUnit=None, PortDelayValue=None, ProtocolItem=None, ReportSequenceError=None, ReportTputRateUnit=None, Rfc2889ordering=None, ServiceIterations=None, ServicesList=None, SkipDefaultPassFailEvaluation=None, StaggeredStart=None, TestTrafficType=None, TransmitMode=None, TxDelay=None):
		"""Updates a child instance of testConfig on the server.

		Args:
			AlgorithmType (str(srvConfiguration|srvPerformance)): The type of algorithm used.
			CalculateJitter (bool): Calculates the interval between timestamps of PGID packet arrivals.
			CalculateLatency (bool): Calculates and reports latency.
			ContinuePassFailed (bool): NOT DEFINED
			CurrentService (str): The service in use currently.
			DelayAfterTransmit (number): Specifies the amount of delay after every transmit.
			Duration (number): The duration of the test in hours, which is used to calculate the number of frames to transmit.
			DurationLabel (str): The label defining the traffic duration time.
			EnableBurstTest (bool): If true, enables burst test.
			EnableDataIntegrity (bool): If true, enables data integrity test.
			EnableLatencyPassFailLabel (str): The latency pass fail criteria is set.
			EnableLayer1Rate (bool): NOT DEFINED
			EnableStandardDeviationPassFailLabel (str): Standard Deviation for the Pass/Fail criteria is set.
			ForceRegenerate (bool): Initiates a forced regeneration.
			FrameDataDetailedResults (bool): NOT DEFINED
			FrameLossFramesMode (str): NOT DEFINED
			FrameSizeMode (str(custom|customlist|increment|random)): This attribute is the frame size mode for the Quad Gaussian.
			Gap (number): The gap in transmission of frames.
			GenerateTrackingOptionAggregationFiles (bool): If true, enables the tracking option in aggregation files.
			IsColorAware (bool): If true, it becomes aware of the color.
			IsServicePeformanceMode (str): The service performance mode.
			IterationInitialRate (str): The initial rate of iteration.
			IterationStep (str): The iteration step.
			LatencyBins (str): Sets the latency bins statistics.
			LatencyBinsEnabled (bool): Enables the latency bins statistics.
			LatencyType (str(cutThrough|mef|storeForward)): The type of latency.
			LearnSnoopConfig (bool): The learned snoop configuration.
			NoOfFrames (str): The number of frames sent.
			Numtrials (number): This signifies the Number of trials.
			PortDelayEnabled (bool): NOT DEFINED
			PortDelayUnit (str(bytes|nanoseconds)): Sets the port delay unit in which it will be measured.
			PortDelayValue (number): Sets the port delay value.
			ProtocolItem (list(str[None|/api/v1/sessions/1/ixnetwork/vport|/api/v1/sessions/1/ixnetwork/vport?deepchild=lan])): Protocol Items
			ReportSequenceError (bool): If true, the sequence error, if found, is reported.
			ReportTputRateUnit (str(gbps|gBps|kbps|kBps|mbps|mBps)): The unit of rate for throughput.
			Rfc2889ordering (str(noOrdering|unchanged|val2889Ordering)): NOT DEFINED
			ServiceIterations (str): Number of service iterations.
			ServicesList (str): The list of service.
			SkipDefaultPassFailEvaluation (bool): If true, it skips the default pass fail evaluation.
			StaggeredStart (bool): Staggered start of traffic.
			TestTrafficType (str): It gives the test traffic type.
			TransmitMode (str(noFrames|useDuration)): The transmit mode for this traffic item.
			TxDelay (number): The minimum delay between successive packets.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def Apply(self):
		"""Executes the apply operation on the server.

		Applies the specified Quick Test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('apply', payload=payload, response_object=None)

	def ApplyAsync(self):
		"""Executes the applyAsync operation on the server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('applyAsync', payload=payload, response_object=None)

	def ApplyAsyncResult(self):
		"""Executes the applyAsyncResult operation on the server.

			Returns:
				bool: 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('applyAsyncResult', payload=payload, response_object=None)

	def ApplyITWizardConfiguration(self):
		"""Executes the applyITWizardConfiguration operation on the server.

		Applies the specified Quick Test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('applyITWizardConfiguration', payload=payload, response_object=None)

	def GenerateReport(self):
		"""Executes the generateReport operation on the server.

		Generate a PDF report for the last succesfull test run.

			Returns:
				str: This method is asynchronous and has no return value.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('generateReport', payload=payload, response_object=None)

	def Run(self, *args, **kwargs):
		"""Executes the run operation on the server.

		Starts the specified Quick Test and waits for its execution to finish.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		run()list

			Returns:
				list(str): This method is synchronous and returns the result of the test.

		run(InputParameters:string)list
			Args:
				args[0] is InputParameters (str): The input arguments of the test.

			Returns:
				list(str): This method is synchronous and returns the result of the test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('run', payload=payload, response_object=None)

	def Start(self, *args, **kwargs):
		"""Executes the start operation on the server.

		Starts the specified Quick Test.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		start()

		start(InputParameters:string)
			Args:
				args[0] is InputParameters (str): The input arguments of the test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('start', payload=payload, response_object=None)

	def Stop(self):
		"""Executes the stop operation on the server.

		Stops the currently running Quick Test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('stop', payload=payload, response_object=None)

	def WaitForTest(self):
		"""Executes the waitForTest operation on the server.

		Waits for the execution of the specified Quick Test to be completed.

			Returns:
				list(str): This method is synchronous and returns the result of the test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('waitForTest', payload=payload, response_object=None)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class MplsOam(Base):
	"""The MplsOam class encapsulates a user managed mplsOam node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the MplsOam property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'mplsOam'

	def __init__(self, parent):
		super(MplsOam, self).__init__(parent)

	@property
	def LearnedInfo(self):
		"""An instance of the LearnedInfo class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.learnedinfo.learnedinfo.LearnedInfo)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.learnedinfo.learnedinfo import LearnedInfo
		return LearnedInfo(self)

	@property
	def Active(self):
		"""Activate/Deactivate Configuration

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('active')

	@property
	def BfdCvType(self):
		"""This signifies the BFD Connectivity Verification type

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('bfdCvType')

	@property
	def BfdDiscriminatorEnd(self):
		"""This signifies the last BFD Discriminator value. This value should be greater than the BFD Discriminator Start value

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('bfdDiscriminatorEnd')

	@property
	def BfdDiscriminatorStart(self):
		"""This signifies the first BFD Discriminator value

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('bfdDiscriminatorStart')

	@property
	def ConnectedVia(self):
		"""DEPRECATED List of layers this layer used to connect to the wire

		Returns:
			list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])
		"""
		return self._get_attribute('connectedVia')
	@ConnectedVia.setter
	def ConnectedVia(self, value):
		self._set_attribute('connectedVia', value)

	@property
	def ControlChannel(self):
		"""DEPRECATED This signifies the communication control channel

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('controlChannel')

	@property
	def Count(self):
		"""DEPRECATED Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group

		Returns:
			number
		"""
		return self._get_attribute('count')

	@property
	def DescriptiveName(self):
		"""DEPRECATED Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but maybe offers more context

		Returns:
			str
		"""
		return self._get_attribute('descriptiveName')

	@property
	def DestinationAddressIpv4(self):
		"""DEPRECATED The destination IPv4 Address

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('destinationAddressIpv4')

	@property
	def DownstreamAddressType(self):
		"""DEPRECATED This signifies the address Type of the downstream traffic

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('downstreamAddressType')

	@property
	def DownstreamInterfaceAddressNumbered(self):
		"""DEPRECATED This signifies the interface address of the downstream traffic in IPv4 format

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('downstreamInterfaceAddressNumbered')

	@property
	def DownstreamInterfaceAddressUnnumbered(self):
		"""DEPRECATED This signifies the interface address of the downstream traffic

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('downstreamInterfaceAddressUnnumbered')

	@property
	def DownstreamIpAddress(self):
		"""DEPRECATED This signifies the IPv4/IPv6 address of the downstream traffic

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('downstreamIpAddress')

	@property
	def EchoRequestInterval(self):
		"""DEPRECATED This signifies the minimum interval, in milliseconds, between received Echo packets that this interface is capable of supporting

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('echoRequestInterval')

	@property
	def EchoResponseTimeout(self):
		"""DEPRECATED This signifies the minimum timeout interval, in milliseconds, between received Echo packets

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('echoResponseTimeout')

	@property
	def EnableDSIflag(self):
		"""DEPRECATED This signifies the activation of the DS I Flag

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('enableDSIflag')

	@property
	def EnableDownstreamMappingTlv(self):
		"""DEPRECATED This signifies the enable of the downstream mapping TLV

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('enableDownstreamMappingTlv')

	@property
	def EnableDsNflag(self):
		"""DEPRECATED This signifies the activation of the DS N Flag

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('enableDsNflag')

	@property
	def EnableFecValidation(self):
		"""DEPRECATED Selection of the check box enables FEC validation

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('enableFecValidation')

	@property
	def EnablePeriodicPing(self):
		"""DEPRECATED If true, the router is pinged at regular intervals

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('enablePeriodicPing')

	@property
	def Errors(self):
		"""DEPRECATED A list of errors that have occurred

		Returns:
			list(dict(arg1:str[None|/api/v1/sessions/1/ixnetwork/?deepchild=*],arg2:list[str]))
		"""
		return self._get_attribute('errors')

	@property
	def FlapTxIntervals(self):
		"""DEPRECATED This signifies the number of seconds between route flaps for BFD. A value of zero means no flapping

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('flapTxIntervals')

	@property
	def IncludePadTlv(self):
		"""DEPRECATED If true, includes Pad TLV in triggered ping

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('includePadTlv')

	@property
	def IncludeVendorEnterpriseNumbeTlv(self):
		"""DEPRECATED If true, include the TLV number of the vendor, in triggered ping

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('includeVendorEnterpriseNumbeTlv')

	@property
	def LocalRouterId(self):
		"""DEPRECATED The MPLOAM Router ID value, in IPv4 format.

		Returns:
			list(str)
		"""
		return self._get_attribute('localRouterId')

	@property
	def MinRxInterval(self):
		"""DEPRECATED This signifies the minimum interval, in milliseconds, between received BFD Control packets that this interface is capable of supporting

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('minRxInterval')

	@property
	def Multiplier(self):
		"""DEPRECATED Number of layer instances per parent instance (multiplier)

		Returns:
			number
		"""
		return self._get_attribute('multiplier')
	@Multiplier.setter
	def Multiplier(self, value):
		self._set_attribute('multiplier', value)

	@property
	def Name(self):
		"""DEPRECATED Name of NGPF element, guaranteed to be unique in Scenario

		Returns:
			str
		"""
		return self._get_attribute('name')
	@Name.setter
	def Name(self, value):
		self._set_attribute('name', value)

	@property
	def PadTlvFirstOctet(self):
		"""DEPRECATED This signifies the selection of the first octet of the Pad TLV

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('padTlvFirstOctet')

	@property
	def PadTlvLength(self):
		"""DEPRECATED This signifies the specification of the length of the Pad TLV

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('padTlvLength')

	@property
	def ReplyMode(self):
		"""DEPRECATED This signifies the selection of the mode of reply

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('replyMode')

	@property
	def SessionStatus(self):
		"""DEPRECATED Current state of protocol session: Not Started - session negotiation not started, the session is not active yet. Down - actively trying to bring up a protocol session, but negotiation is didn't successfully complete (yet). Up - session came up successfully.

		Returns:
			list(str[down|notStarted|up])
		"""
		return self._get_attribute('sessionStatus')

	@property
	def StackedLayers(self):
		"""DEPRECATED List of secondary (many to one) child layer protocols

		Returns:
			list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])
		"""
		return self._get_attribute('stackedLayers')
	@StackedLayers.setter
	def StackedLayers(self, value):
		self._set_attribute('stackedLayers', value)

	@property
	def StateCounts(self):
		"""DEPRECATED A list of values that indicates the total number of sessions, the number of sessions not started, the number of sessions down and the number of sessions that are up

		Returns:
			dict(total:number,notStarted:number,down:number,up:number)
		"""
		return self._get_attribute('stateCounts')

	@property
	def Status(self):
		"""DEPRECATED Running status of associated network element. Once in Started state, protocol sessions will begin to negotiate.

		Returns:
			str(configured|error|mixed|notStarted|started|starting|stopping)
		"""
		return self._get_attribute('status')

	@property
	def TimeoutMultiplier(self):
		"""DEPRECATED This signifies the negotiated transmit interval, multiplied by this value, provides the detection time for the interface

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('timeoutMultiplier')

	@property
	def TxInterval(self):
		"""DEPRECATED This signifies the minimum interval, in milliseconds, that the interface would like to use when transmitting BFD Control packets

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('txInterval')

	@property
	def VendorEnterpriseNumber(self):
		"""DEPRECATED This signifies the specification of the enterprise number of the vendor

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('vendorEnterpriseNumber')

	def update(self, ConnectedVia=None, Multiplier=None, Name=None, StackedLayers=None):
		"""Updates a child instance of mplsOam on the server.

		This method has some named parameters with a type: obj (Multivalue).
		The Multivalue class has the associated documentation that details the possible values for those named parameters.

		Args:
			ConnectedVia (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of layers this layer used to connect to the wire
			Multiplier (number): Number of layer instances per parent instance (multiplier)
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario
			StackedLayers (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of secondary (many to one) child layer protocols

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, ConnectedVia=None, Multiplier=None, Name=None, StackedLayers=None):
		"""Adds a new mplsOam node on the server and retrieves it in this instance.

		Args:
			ConnectedVia (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of layers this layer used to connect to the wire
			Multiplier (number): Number of layer instances per parent instance (multiplier)
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario
			StackedLayers (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of secondary (many to one) child layer protocols

		Returns:
			self: This instance with all currently retrieved mplsOam data using find and the newly added mplsOam data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the mplsOam data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, ConnectedVia=None, Count=None, DescriptiveName=None, Errors=None, LocalRouterId=None, Multiplier=None, Name=None, SessionStatus=None, StackedLayers=None, StateCounts=None, Status=None):
		"""Finds and retrieves mplsOam data from the server.

		All named parameters support regex and can be used to selectively retrieve mplsOam data from the server.
		By default the find method takes no parameters and will retrieve all mplsOam data from the server.

		Args:
			ConnectedVia (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of layers this layer used to connect to the wire
			Count (number): Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group
			DescriptiveName (str): Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but maybe offers more context
			Errors (list(dict(arg1:str[None|/api/v1/sessions/1/ixnetwork/?deepchild=*],arg2:list[str]))): A list of errors that have occurred
			LocalRouterId (list(str)): The MPLOAM Router ID value, in IPv4 format.
			Multiplier (number): Number of layer instances per parent instance (multiplier)
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario
			SessionStatus (list(str[down|notStarted|up])): Current state of protocol session: Not Started - session negotiation not started, the session is not active yet. Down - actively trying to bring up a protocol session, but negotiation is didn't successfully complete (yet). Up - session came up successfully.
			StackedLayers (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of secondary (many to one) child layer protocols
			StateCounts (dict(total:number,notStarted:number,down:number,up:number)): A list of values that indicates the total number of sessions, the number of sessions not started, the number of sessions down and the number of sessions that are up
			Status (str(configured|error|mixed|notStarted|started|starting|stopping)): Running status of associated network element. Once in Started state, protocol sessions will begin to negotiate.

		Returns:
			self: This instance with matching mplsOam data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of mplsOam data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the mplsOam data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)

	def get_device_ids(self, PortNames=None, Active=None, BfdCvType=None, BfdDiscriminatorEnd=None, BfdDiscriminatorStart=None, ControlChannel=None, DestinationAddressIpv4=None, DownstreamAddressType=None, DownstreamInterfaceAddressNumbered=None, DownstreamInterfaceAddressUnnumbered=None, DownstreamIpAddress=None, EchoRequestInterval=None, EchoResponseTimeout=None, EnableDSIflag=None, EnableDownstreamMappingTlv=None, EnableDsNflag=None, EnableFecValidation=None, EnablePeriodicPing=None, FlapTxIntervals=None, IncludePadTlv=None, IncludeVendorEnterpriseNumbeTlv=None, MinRxInterval=None, PadTlvFirstOctet=None, PadTlvLength=None, ReplyMode=None, TimeoutMultiplier=None, TxInterval=None, VendorEnterpriseNumber=None):
		"""Base class infrastructure that gets a list of mplsOam device ids encapsulated by this object.

		Use the optional regex parameters in the method to refine the list of device ids encapsulated by this object.

		Args:
			PortNames (str): optional regex of port names
			Active (str): optional regex of active
			BfdCvType (str): optional regex of bfdCvType
			BfdDiscriminatorEnd (str): optional regex of bfdDiscriminatorEnd
			BfdDiscriminatorStart (str): optional regex of bfdDiscriminatorStart
			ControlChannel (str): optional regex of controlChannel
			DestinationAddressIpv4 (str): optional regex of destinationAddressIpv4
			DownstreamAddressType (str): optional regex of downstreamAddressType
			DownstreamInterfaceAddressNumbered (str): optional regex of downstreamInterfaceAddressNumbered
			DownstreamInterfaceAddressUnnumbered (str): optional regex of downstreamInterfaceAddressUnnumbered
			DownstreamIpAddress (str): optional regex of downstreamIpAddress
			EchoRequestInterval (str): optional regex of echoRequestInterval
			EchoResponseTimeout (str): optional regex of echoResponseTimeout
			EnableDSIflag (str): optional regex of enableDSIflag
			EnableDownstreamMappingTlv (str): optional regex of enableDownstreamMappingTlv
			EnableDsNflag (str): optional regex of enableDsNflag
			EnableFecValidation (str): optional regex of enableFecValidation
			EnablePeriodicPing (str): optional regex of enablePeriodicPing
			FlapTxIntervals (str): optional regex of flapTxIntervals
			IncludePadTlv (str): optional regex of includePadTlv
			IncludeVendorEnterpriseNumbeTlv (str): optional regex of includeVendorEnterpriseNumbeTlv
			MinRxInterval (str): optional regex of minRxInterval
			PadTlvFirstOctet (str): optional regex of padTlvFirstOctet
			PadTlvLength (str): optional regex of padTlvLength
			ReplyMode (str): optional regex of replyMode
			TimeoutMultiplier (str): optional regex of timeoutMultiplier
			TxInterval (str): optional regex of txInterval
			VendorEnterpriseNumber (str): optional regex of vendorEnterpriseNumber

		Returns:
			list(int): A list of device ids that meets the regex criteria provided in the method parameters

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._get_ngpf_device_ids(locals())

	def ClearAllLearnedInfo(self, *args, **kwargs):
		"""Executes the clearAllLearnedInfo operation on the server.

		Clears ALL Learned LSP Information By PCC Device.

		clearAllLearnedInfo(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin.An empty list indicates all instances in the plugin.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('clearAllLearnedInfo', payload=payload, response_object=None)

	def FetchAndUpdateConfigFromCloud(self, *args, **kwargs):
		"""Executes the fetchAndUpdateConfigFromCloud operation on the server.

		fetchAndUpdateConfigFromCloud(Mode:string)
			Args:
				args[0] is Mode (str): 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('fetchAndUpdateConfigFromCloud', payload=payload, response_object=None)

	def GetAllLearnedInfo(self, *args, **kwargs):
		"""Executes the getAllLearnedInfo operation on the server.

		MPLSOAM learned Info

		getAllLearnedInfo(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin.An empty list indicates all instances in the plugin.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('getAllLearnedInfo', payload=payload, response_object=None)

	def RestartDown(self, *args, **kwargs):
		"""Executes the restartDown operation on the server.

		Stop and start interfaces and sessions that are in Down state.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		restartDown()

		restartDown(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		restartDown(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('restartDown', payload=payload, response_object=None)

	def Start(self, *args, **kwargs):
		"""Executes the start operation on the server.

		Activate Interface

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		start()

		start(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		start(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('start', payload=payload, response_object=None)

	def Stop(self, *args, **kwargs):
		"""Executes the stop operation on the server.

		Deactivate Interface

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		stop()

		stop(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		stop(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('stop', payload=payload, response_object=None)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class Link(Base):
	"""The Link class encapsulates a user managed link node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the Link property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'link'

	def __init__(self, parent):
		super(Link, self).__init__(parent)

	@property
	def DiscoveredLearnedInfo(self):
		"""An instance of the DiscoveredLearnedInfo class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.linkoam.link.discoveredlearnedinfo.discoveredlearnedinfo.DiscoveredLearnedInfo)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.linkoam.link.discoveredlearnedinfo.discoveredlearnedinfo import DiscoveredLearnedInfo
		return DiscoveredLearnedInfo(self)

	@property
	def ErroredFramePeriodTlv(self):
		"""An instance of the ErroredFramePeriodTlv class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.linkoam.link.erroredframeperiodtlv.erroredframeperiodtlv.ErroredFramePeriodTlv)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.linkoam.link.erroredframeperiodtlv.erroredframeperiodtlv import ErroredFramePeriodTlv
		return ErroredFramePeriodTlv(self)._select()

	@property
	def ErroredFrameSecondsSummaryTlv(self):
		"""An instance of the ErroredFrameSecondsSummaryTlv class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.linkoam.link.erroredframesecondssummarytlv.erroredframesecondssummarytlv.ErroredFrameSecondsSummaryTlv)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.linkoam.link.erroredframesecondssummarytlv.erroredframesecondssummarytlv import ErroredFrameSecondsSummaryTlv
		return ErroredFrameSecondsSummaryTlv(self)._select()

	@property
	def ErroredFrameTlv(self):
		"""An instance of the ErroredFrameTlv class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.linkoam.link.erroredframetlv.erroredframetlv.ErroredFrameTlv)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.linkoam.link.erroredframetlv.erroredframetlv import ErroredFrameTlv
		return ErroredFrameTlv(self)._select()

	@property
	def ErroredSymbolPeriodTlv(self):
		"""An instance of the ErroredSymbolPeriodTlv class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.linkoam.link.erroredsymbolperiodtlv.erroredsymbolperiodtlv.ErroredSymbolPeriodTlv)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.linkoam.link.erroredsymbolperiodtlv.erroredsymbolperiodtlv import ErroredSymbolPeriodTlv
		return ErroredSymbolPeriodTlv(self)._select()

	@property
	def EventNotificationLearnedInfo(self):
		"""An instance of the EventNotificationLearnedInfo class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.linkoam.link.eventnotificationlearnedinfo.eventnotificationlearnedinfo.EventNotificationLearnedInfo)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.linkoam.link.eventnotificationlearnedinfo.eventnotificationlearnedinfo import EventNotificationLearnedInfo
		return EventNotificationLearnedInfo(self)

	@property
	def Interface(self):
		"""An instance of the Interface class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.linkoam.link.interface.interface.Interface)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.linkoam.link.interface.interface import Interface
		return Interface(self)

	@property
	def OrganizationSpecificEventTlv(self):
		"""An instance of the OrganizationSpecificEventTlv class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.linkoam.link.organizationspecificeventtlv.organizationspecificeventtlv.OrganizationSpecificEventTlv)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.linkoam.link.organizationspecificeventtlv.organizationspecificeventtlv import OrganizationSpecificEventTlv
		return OrganizationSpecificEventTlv(self)._select()

	@property
	def OrganizationSpecificInfoTlv(self):
		"""An instance of the OrganizationSpecificInfoTlv class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.linkoam.link.organizationspecificinfotlv.organizationspecificinfotlv.OrganizationSpecificInfoTlv)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.linkoam.link.organizationspecificinfotlv.organizationspecificinfotlv import OrganizationSpecificInfoTlv
		return OrganizationSpecificInfoTlv(self)

	@property
	def OrganizationSpecificOamPduData(self):
		"""An instance of the OrganizationSpecificOamPduData class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.linkoam.link.organizationspecificoampdudata.organizationspecificoampdudata.OrganizationSpecificOamPduData)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.linkoam.link.organizationspecificoampdudata.organizationspecificoampdudata import OrganizationSpecificOamPduData
		return OrganizationSpecificOamPduData(self)

	@property
	def VarDescriptor(self):
		"""An instance of the VarDescriptor class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.linkoam.link.vardescriptor.vardescriptor.VarDescriptor)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.linkoam.link.vardescriptor.vardescriptor import VarDescriptor
		return VarDescriptor(self)

	@property
	def VariableRequestLearnedInfo(self):
		"""An instance of the VariableRequestLearnedInfo class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.linkoam.link.variablerequestlearnedinfo.variablerequestlearnedinfo.VariableRequestLearnedInfo)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.linkoam.link.variablerequestlearnedinfo.variablerequestlearnedinfo import VariableRequestLearnedInfo
		return VariableRequestLearnedInfo(self)

	@property
	def VariableResponseDatabase(self):
		"""An instance of the VariableResponseDatabase class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.linkoam.link.variableresponsedatabase.variableresponsedatabase.VariableResponseDatabase)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.linkoam.link.variableresponsedatabase.variableresponsedatabase import VariableResponseDatabase
		return VariableResponseDatabase(self)

	@property
	def DisableInformationPduTx(self):
		"""

		Returns:
			bool
		"""
		return self._get_attribute('disableInformationPduTx')
	@DisableInformationPduTx.setter
	def DisableInformationPduTx(self, value):
		self._set_attribute('disableInformationPduTx', value)

	@property
	def DisableNonInformationPduTx(self):
		"""

		Returns:
			bool
		"""
		return self._get_attribute('disableNonInformationPduTx')
	@DisableNonInformationPduTx.setter
	def DisableNonInformationPduTx(self, value):
		self._set_attribute('disableNonInformationPduTx', value)

	@property
	def EnableCriticalEvent(self):
		"""

		Returns:
			bool
		"""
		return self._get_attribute('enableCriticalEvent')
	@EnableCriticalEvent.setter
	def EnableCriticalEvent(self, value):
		self._set_attribute('enableCriticalEvent', value)

	@property
	def EnableDyingGasp(self):
		"""

		Returns:
			bool
		"""
		return self._get_attribute('enableDyingGasp')
	@EnableDyingGasp.setter
	def EnableDyingGasp(self, value):
		self._set_attribute('enableDyingGasp', value)

	@property
	def EnableLinkFault(self):
		"""

		Returns:
			bool
		"""
		return self._get_attribute('enableLinkFault')
	@EnableLinkFault.setter
	def EnableLinkFault(self, value):
		self._set_attribute('enableLinkFault', value)

	@property
	def EnableLoopbackResponse(self):
		"""

		Returns:
			bool
		"""
		return self._get_attribute('enableLoopbackResponse')
	@EnableLoopbackResponse.setter
	def EnableLoopbackResponse(self, value):
		self._set_attribute('enableLoopbackResponse', value)

	@property
	def EnableVariableResponse(self):
		"""

		Returns:
			bool
		"""
		return self._get_attribute('enableVariableResponse')
	@EnableVariableResponse.setter
	def EnableVariableResponse(self, value):
		self._set_attribute('enableVariableResponse', value)

	@property
	def Enabled(self):
		"""

		Returns:
			bool
		"""
		return self._get_attribute('enabled')
	@Enabled.setter
	def Enabled(self, value):
		self._set_attribute('enabled', value)

	@property
	def EthernetTypeUsedForDataTraffic(self):
		"""

		Returns:
			number
		"""
		return self._get_attribute('ethernetTypeUsedForDataTraffic')
	@EthernetTypeUsedForDataTraffic.setter
	def EthernetTypeUsedForDataTraffic(self, value):
		self._set_attribute('ethernetTypeUsedForDataTraffic', value)

	@property
	def EventInterval(self):
		"""

		Returns:
			number
		"""
		return self._get_attribute('eventInterval')
	@EventInterval.setter
	def EventInterval(self, value):
		self._set_attribute('eventInterval', value)

	@property
	def InformationPduCountPerSecond(self):
		"""

		Returns:
			number
		"""
		return self._get_attribute('informationPduCountPerSecond')
	@InformationPduCountPerSecond.setter
	def InformationPduCountPerSecond(self, value):
		self._set_attribute('informationPduCountPerSecond', value)

	@property
	def IsDiscLearnedInfoRefreshed(self):
		"""

		Returns:
			bool
		"""
		return self._get_attribute('isDiscLearnedInfoRefreshed')

	@property
	def IsEventNotificationLearnedInfoRefreshed(self):
		"""

		Returns:
			bool
		"""
		return self._get_attribute('isEventNotificationLearnedInfoRefreshed')

	@property
	def IsLoopbackLearnedInfoRefreshed(self):
		"""

		Returns:
			bool
		"""
		return self._get_attribute('isLoopbackLearnedInfoRefreshed')

	@property
	def IsVariableRequestLearnedInfoRefreshed(self):
		"""

		Returns:
			bool
		"""
		return self._get_attribute('isVariableRequestLearnedInfoRefreshed')

	@property
	def LinkEventTxMode(self):
		"""

		Returns:
			str(single|periodic)
		"""
		return self._get_attribute('linkEventTxMode')
	@LinkEventTxMode.setter
	def LinkEventTxMode(self, value):
		self._set_attribute('linkEventTxMode', value)

	@property
	def LocalLostLinkTimer(self):
		"""

		Returns:
			number
		"""
		return self._get_attribute('localLostLinkTimer')
	@LocalLostLinkTimer.setter
	def LocalLostLinkTimer(self, value):
		self._set_attribute('localLostLinkTimer', value)

	@property
	def LoopbackCmd(self):
		"""

		Returns:
			str(disableLoopback|enableLoopback)
		"""
		return self._get_attribute('loopbackCmd')
	@LoopbackCmd.setter
	def LoopbackCmd(self, value):
		self._set_attribute('loopbackCmd', value)

	@property
	def LoopbackTimeout(self):
		"""

		Returns:
			number
		"""
		return self._get_attribute('loopbackTimeout')
	@LoopbackTimeout.setter
	def LoopbackTimeout(self, value):
		self._set_attribute('loopbackTimeout', value)

	@property
	def MacAddress(self):
		"""

		Returns:
			str
		"""
		return self._get_attribute('macAddress')
	@MacAddress.setter
	def MacAddress(self, value):
		self._set_attribute('macAddress', value)

	@property
	def MaxOamPduSize(self):
		"""

		Returns:
			number
		"""
		return self._get_attribute('maxOamPduSize')
	@MaxOamPduSize.setter
	def MaxOamPduSize(self, value):
		self._set_attribute('maxOamPduSize', value)

	@property
	def OperationMode(self):
		"""

		Returns:
			str(active|passive)
		"""
		return self._get_attribute('operationMode')
	@OperationMode.setter
	def OperationMode(self, value):
		self._set_attribute('operationMode', value)

	@property
	def Oui(self):
		"""

		Returns:
			str
		"""
		return self._get_attribute('oui')
	@Oui.setter
	def Oui(self, value):
		self._set_attribute('oui', value)

	@property
	def OverrideLocalEvaluating(self):
		"""

		Returns:
			bool
		"""
		return self._get_attribute('overrideLocalEvaluating')
	@OverrideLocalEvaluating.setter
	def OverrideLocalEvaluating(self, value):
		self._set_attribute('overrideLocalEvaluating', value)

	@property
	def OverrideLocalSatisfied(self):
		"""

		Returns:
			bool
		"""
		return self._get_attribute('overrideLocalSatisfied')
	@OverrideLocalSatisfied.setter
	def OverrideLocalSatisfied(self, value):
		self._set_attribute('overrideLocalSatisfied', value)

	@property
	def OverrideLocalStable(self):
		"""

		Returns:
			bool
		"""
		return self._get_attribute('overrideLocalStable')
	@OverrideLocalStable.setter
	def OverrideLocalStable(self, value):
		self._set_attribute('overrideLocalStable', value)

	@property
	def OverrideRemoteEvaluating(self):
		"""

		Returns:
			bool
		"""
		return self._get_attribute('overrideRemoteEvaluating')
	@OverrideRemoteEvaluating.setter
	def OverrideRemoteEvaluating(self, value):
		self._set_attribute('overrideRemoteEvaluating', value)

	@property
	def OverrideRemoteStable(self):
		"""

		Returns:
			bool
		"""
		return self._get_attribute('overrideRemoteStable')
	@OverrideRemoteStable.setter
	def OverrideRemoteStable(self, value):
		self._set_attribute('overrideRemoteStable', value)

	@property
	def OverrideRevision(self):
		"""

		Returns:
			bool
		"""
		return self._get_attribute('overrideRevision')
	@OverrideRevision.setter
	def OverrideRevision(self, value):
		self._set_attribute('overrideRevision', value)

	@property
	def OverrideSequenceNumber(self):
		"""

		Returns:
			bool
		"""
		return self._get_attribute('overrideSequenceNumber')
	@OverrideSequenceNumber.setter
	def OverrideSequenceNumber(self, value):
		self._set_attribute('overrideSequenceNumber', value)

	@property
	def Revision(self):
		"""

		Returns:
			number
		"""
		return self._get_attribute('revision')
	@Revision.setter
	def Revision(self, value):
		self._set_attribute('revision', value)

	@property
	def SequenceNumber(self):
		"""

		Returns:
			number
		"""
		return self._get_attribute('sequenceNumber')
	@SequenceNumber.setter
	def SequenceNumber(self, value):
		self._set_attribute('sequenceNumber', value)

	@property
	def SupportsInterpretingLinkEvents(self):
		"""

		Returns:
			bool
		"""
		return self._get_attribute('supportsInterpretingLinkEvents')
	@SupportsInterpretingLinkEvents.setter
	def SupportsInterpretingLinkEvents(self, value):
		self._set_attribute('supportsInterpretingLinkEvents', value)

	@property
	def SupportsRemoteLoopback(self):
		"""

		Returns:
			bool
		"""
		return self._get_attribute('supportsRemoteLoopback')
	@SupportsRemoteLoopback.setter
	def SupportsRemoteLoopback(self, value):
		self._set_attribute('supportsRemoteLoopback', value)

	@property
	def SupportsUnidirectionalMode(self):
		"""

		Returns:
			bool
		"""
		return self._get_attribute('supportsUnidirectionalMode')
	@SupportsUnidirectionalMode.setter
	def SupportsUnidirectionalMode(self, value):
		self._set_attribute('supportsUnidirectionalMode', value)

	@property
	def SupportsVariableRetrieval(self):
		"""

		Returns:
			bool
		"""
		return self._get_attribute('supportsVariableRetrieval')
	@SupportsVariableRetrieval.setter
	def SupportsVariableRetrieval(self, value):
		self._set_attribute('supportsVariableRetrieval', value)

	@property
	def UpdateRequired(self):
		"""

		Returns:
			bool
		"""
		return self._get_attribute('updateRequired')

	@property
	def VariableResponseTimeout(self):
		"""

		Returns:
			number
		"""
		return self._get_attribute('variableResponseTimeout')
	@VariableResponseTimeout.setter
	def VariableResponseTimeout(self, value):
		self._set_attribute('variableResponseTimeout', value)

	@property
	def VendorSpecificInformation(self):
		"""

		Returns:
			str
		"""
		return self._get_attribute('vendorSpecificInformation')
	@VendorSpecificInformation.setter
	def VendorSpecificInformation(self, value):
		self._set_attribute('vendorSpecificInformation', value)

	@property
	def Version(self):
		"""

		Returns:
			number
		"""
		return self._get_attribute('version')
	@Version.setter
	def Version(self, value):
		self._set_attribute('version', value)

	def update(self, DisableInformationPduTx=None, DisableNonInformationPduTx=None, EnableCriticalEvent=None, EnableDyingGasp=None, EnableLinkFault=None, EnableLoopbackResponse=None, EnableVariableResponse=None, Enabled=None, EthernetTypeUsedForDataTraffic=None, EventInterval=None, InformationPduCountPerSecond=None, LinkEventTxMode=None, LocalLostLinkTimer=None, LoopbackCmd=None, LoopbackTimeout=None, MacAddress=None, MaxOamPduSize=None, OperationMode=None, Oui=None, OverrideLocalEvaluating=None, OverrideLocalSatisfied=None, OverrideLocalStable=None, OverrideRemoteEvaluating=None, OverrideRemoteStable=None, OverrideRevision=None, OverrideSequenceNumber=None, Revision=None, SequenceNumber=None, SupportsInterpretingLinkEvents=None, SupportsRemoteLoopback=None, SupportsUnidirectionalMode=None, SupportsVariableRetrieval=None, VariableResponseTimeout=None, VendorSpecificInformation=None, Version=None):
		"""Updates a child instance of link on the server.

		Args:
			DisableInformationPduTx (bool): 
			DisableNonInformationPduTx (bool): 
			EnableCriticalEvent (bool): 
			EnableDyingGasp (bool): 
			EnableLinkFault (bool): 
			EnableLoopbackResponse (bool): 
			EnableVariableResponse (bool): 
			Enabled (bool): 
			EthernetTypeUsedForDataTraffic (number): 
			EventInterval (number): 
			InformationPduCountPerSecond (number): 
			LinkEventTxMode (str(single|periodic)): 
			LocalLostLinkTimer (number): 
			LoopbackCmd (str(disableLoopback|enableLoopback)): 
			LoopbackTimeout (number): 
			MacAddress (str): 
			MaxOamPduSize (number): 
			OperationMode (str(active|passive)): 
			Oui (str): 
			OverrideLocalEvaluating (bool): 
			OverrideLocalSatisfied (bool): 
			OverrideLocalStable (bool): 
			OverrideRemoteEvaluating (bool): 
			OverrideRemoteStable (bool): 
			OverrideRevision (bool): 
			OverrideSequenceNumber (bool): 
			Revision (number): 
			SequenceNumber (number): 
			SupportsInterpretingLinkEvents (bool): 
			SupportsRemoteLoopback (bool): 
			SupportsUnidirectionalMode (bool): 
			SupportsVariableRetrieval (bool): 
			VariableResponseTimeout (number): 
			VendorSpecificInformation (str): 
			Version (number): 

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, DisableInformationPduTx=None, DisableNonInformationPduTx=None, EnableCriticalEvent=None, EnableDyingGasp=None, EnableLinkFault=None, EnableLoopbackResponse=None, EnableVariableResponse=None, Enabled=None, EthernetTypeUsedForDataTraffic=None, EventInterval=None, InformationPduCountPerSecond=None, LinkEventTxMode=None, LocalLostLinkTimer=None, LoopbackCmd=None, LoopbackTimeout=None, MacAddress=None, MaxOamPduSize=None, OperationMode=None, Oui=None, OverrideLocalEvaluating=None, OverrideLocalSatisfied=None, OverrideLocalStable=None, OverrideRemoteEvaluating=None, OverrideRemoteStable=None, OverrideRevision=None, OverrideSequenceNumber=None, Revision=None, SequenceNumber=None, SupportsInterpretingLinkEvents=None, SupportsRemoteLoopback=None, SupportsUnidirectionalMode=None, SupportsVariableRetrieval=None, VariableResponseTimeout=None, VendorSpecificInformation=None, Version=None):
		"""Adds a new link node on the server and retrieves it in this instance.

		Args:
			DisableInformationPduTx (bool): 
			DisableNonInformationPduTx (bool): 
			EnableCriticalEvent (bool): 
			EnableDyingGasp (bool): 
			EnableLinkFault (bool): 
			EnableLoopbackResponse (bool): 
			EnableVariableResponse (bool): 
			Enabled (bool): 
			EthernetTypeUsedForDataTraffic (number): 
			EventInterval (number): 
			InformationPduCountPerSecond (number): 
			LinkEventTxMode (str(single|periodic)): 
			LocalLostLinkTimer (number): 
			LoopbackCmd (str(disableLoopback|enableLoopback)): 
			LoopbackTimeout (number): 
			MacAddress (str): 
			MaxOamPduSize (number): 
			OperationMode (str(active|passive)): 
			Oui (str): 
			OverrideLocalEvaluating (bool): 
			OverrideLocalSatisfied (bool): 
			OverrideLocalStable (bool): 
			OverrideRemoteEvaluating (bool): 
			OverrideRemoteStable (bool): 
			OverrideRevision (bool): 
			OverrideSequenceNumber (bool): 
			Revision (number): 
			SequenceNumber (number): 
			SupportsInterpretingLinkEvents (bool): 
			SupportsRemoteLoopback (bool): 
			SupportsUnidirectionalMode (bool): 
			SupportsVariableRetrieval (bool): 
			VariableResponseTimeout (number): 
			VendorSpecificInformation (str): 
			Version (number): 

		Returns:
			self: This instance with all currently retrieved link data using find and the newly added link data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the link data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, DisableInformationPduTx=None, DisableNonInformationPduTx=None, EnableCriticalEvent=None, EnableDyingGasp=None, EnableLinkFault=None, EnableLoopbackResponse=None, EnableVariableResponse=None, Enabled=None, EthernetTypeUsedForDataTraffic=None, EventInterval=None, InformationPduCountPerSecond=None, IsDiscLearnedInfoRefreshed=None, IsEventNotificationLearnedInfoRefreshed=None, IsLoopbackLearnedInfoRefreshed=None, IsVariableRequestLearnedInfoRefreshed=None, LinkEventTxMode=None, LocalLostLinkTimer=None, LoopbackCmd=None, LoopbackTimeout=None, MacAddress=None, MaxOamPduSize=None, OperationMode=None, Oui=None, OverrideLocalEvaluating=None, OverrideLocalSatisfied=None, OverrideLocalStable=None, OverrideRemoteEvaluating=None, OverrideRemoteStable=None, OverrideRevision=None, OverrideSequenceNumber=None, Revision=None, SequenceNumber=None, SupportsInterpretingLinkEvents=None, SupportsRemoteLoopback=None, SupportsUnidirectionalMode=None, SupportsVariableRetrieval=None, UpdateRequired=None, VariableResponseTimeout=None, VendorSpecificInformation=None, Version=None):
		"""Finds and retrieves link data from the server.

		All named parameters support regex and can be used to selectively retrieve link data from the server.
		By default the find method takes no parameters and will retrieve all link data from the server.

		Args:
			DisableInformationPduTx (bool): 
			DisableNonInformationPduTx (bool): 
			EnableCriticalEvent (bool): 
			EnableDyingGasp (bool): 
			EnableLinkFault (bool): 
			EnableLoopbackResponse (bool): 
			EnableVariableResponse (bool): 
			Enabled (bool): 
			EthernetTypeUsedForDataTraffic (number): 
			EventInterval (number): 
			InformationPduCountPerSecond (number): 
			IsDiscLearnedInfoRefreshed (bool): 
			IsEventNotificationLearnedInfoRefreshed (bool): 
			IsLoopbackLearnedInfoRefreshed (bool): 
			IsVariableRequestLearnedInfoRefreshed (bool): 
			LinkEventTxMode (str(single|periodic)): 
			LocalLostLinkTimer (number): 
			LoopbackCmd (str(disableLoopback|enableLoopback)): 
			LoopbackTimeout (number): 
			MacAddress (str): 
			MaxOamPduSize (number): 
			OperationMode (str(active|passive)): 
			Oui (str): 
			OverrideLocalEvaluating (bool): 
			OverrideLocalSatisfied (bool): 
			OverrideLocalStable (bool): 
			OverrideRemoteEvaluating (bool): 
			OverrideRemoteStable (bool): 
			OverrideRevision (bool): 
			OverrideSequenceNumber (bool): 
			Revision (number): 
			SequenceNumber (number): 
			SupportsInterpretingLinkEvents (bool): 
			SupportsRemoteLoopback (bool): 
			SupportsUnidirectionalMode (bool): 
			SupportsVariableRetrieval (bool): 
			UpdateRequired (bool): 
			VariableResponseTimeout (number): 
			VendorSpecificInformation (str): 
			Version (number): 

		Returns:
			self: This instance with matching link data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of link data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the link data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)

	def RefreshDiscLearnedInfo(self):
		"""Executes the refreshDiscLearnedInfo operation on the server.

			Returns:
				bool: 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('refreshDiscLearnedInfo', payload=payload, response_object=None)

	def RefreshEventNotificationLearnedInfo(self):
		"""Executes the refreshEventNotificationLearnedInfo operation on the server.

			Returns:
				bool: 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('refreshEventNotificationLearnedInfo', payload=payload, response_object=None)

	def RestartDiscovery(self):
		"""Executes the restartDiscovery operation on the server.

			Returns:
				bool: 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('restartDiscovery', payload=payload, response_object=None)

	def SendLoopback(self):
		"""Executes the sendLoopback operation on the server.

			Returns:
				bool: 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('sendLoopback', payload=payload, response_object=None)

	def SendOrgSpecificPdu(self):
		"""Executes the sendOrgSpecificPdu operation on the server.

			Returns:
				bool: 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('sendOrgSpecificPdu', payload=payload, response_object=None)

	def SendUpdatedParameters(self):
		"""Executes the sendUpdatedParameters operation on the server.

			Returns:
				bool: 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('sendUpdatedParameters', payload=payload, response_object=None)

	def SendVariableRequest(self):
		"""Executes the sendVariableRequest operation on the server.

			Returns:
				bool: 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('sendVariableRequest', payload=payload, response_object=None)

	def StartEventPduTransmission(self):
		"""Executes the startEventPduTransmission operation on the server.

			Returns:
				bool: 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('startEventPduTransmission', payload=payload, response_object=None)

	def StopEventPduTransmission(self):
		"""Executes the stopEventPduTransmission operation on the server.

			Returns:
				bool: 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('stopEventPduTransmission', payload=payload, response_object=None)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class LocalEidRange(Base):
	"""The LocalEidRange class encapsulates a user managed localEidRange node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the LocalEidRange property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'localEidRange'

	def __init__(self, parent):
		super(LocalEidRange, self).__init__(parent)

	@property
	def Locator(self):
		"""An instance of the Locator class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.lisp.router.lispinstance.localeidrange.locator.locator.Locator)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.lisp.router.lispinstance.localeidrange.locator.locator import Locator
		return Locator(self)

	@property
	def Count(self):
		"""It gives details about the count

		Returns:
			number
		"""
		return self._get_attribute('count')
	@Count.setter
	def Count(self, value):
		self._set_attribute('count', value)

	@property
	def EnableProxyMapReplyBit(self):
		"""If true, it enables the proxy map reply bit

		Returns:
			bool
		"""
		return self._get_attribute('enableProxyMapReplyBit')
	@EnableProxyMapReplyBit.setter
	def EnableProxyMapReplyBit(self, value):
		self._set_attribute('enableProxyMapReplyBit', value)

	@property
	def EnableWantMapNotifyBit(self):
		"""If true, it enables the Want map Notify bit

		Returns:
			str(always|duringQuickRegistration|never)
		"""
		return self._get_attribute('enableWantMapNotifyBit')
	@EnableWantMapNotifyBit.setter
	def EnableWantMapNotifyBit(self, value):
		self._set_attribute('enableWantMapNotifyBit', value)

	@property
	def Enabled(self):
		"""If true, it enables the protocol

		Returns:
			bool
		"""
		return self._get_attribute('enabled')
	@Enabled.setter
	def Enabled(self, value):
		self._set_attribute('enabled', value)

	@property
	def Family(self):
		"""It gives details about the family

		Returns:
			str(ipv4|ipv6)
		"""
		return self._get_attribute('family')
	@Family.setter
	def Family(self, value):
		self._set_attribute('family', value)

	@property
	def MaxRecordPerMapRegisterPacket(self):
		"""It gives details about the maximum record per map register packet

		Returns:
			number
		"""
		return self._get_attribute('maxRecordPerMapRegisterPacket')
	@MaxRecordPerMapRegisterPacket.setter
	def MaxRecordPerMapRegisterPacket(self, value):
		self._set_attribute('maxRecordPerMapRegisterPacket', value)

	@property
	def PeriodicRefreshInterval(self):
		"""It gives details about the periodic refresh interval

		Returns:
			number
		"""
		return self._get_attribute('periodicRefreshInterval')
	@PeriodicRefreshInterval.setter
	def PeriodicRefreshInterval(self, value):
		self._set_attribute('periodicRefreshInterval', value)

	@property
	def PrefixLength(self):
		"""it gives details about the prefix length

		Returns:
			number
		"""
		return self._get_attribute('prefixLength')
	@PrefixLength.setter
	def PrefixLength(self, value):
		self._set_attribute('prefixLength', value)

	@property
	def QuickRegistrationPeriod(self):
		"""it gives details about the quick registration period

		Returns:
			number
		"""
		return self._get_attribute('quickRegistrationPeriod')
	@QuickRegistrationPeriod.setter
	def QuickRegistrationPeriod(self, value):
		self._set_attribute('quickRegistrationPeriod', value)

	@property
	def RefreshIntervalInQuickRegistrationPeriod(self):
		"""It refreshs the interval in quick registration periods

		Returns:
			number
		"""
		return self._get_attribute('refreshIntervalInQuickRegistrationPeriod')
	@RefreshIntervalInQuickRegistrationPeriod.setter
	def RefreshIntervalInQuickRegistrationPeriod(self, value):
		self._set_attribute('refreshIntervalInQuickRegistrationPeriod', value)

	@property
	def StartAddress(self):
		"""It gives details about the start address

		Returns:
			str
		"""
		return self._get_attribute('startAddress')
	@StartAddress.setter
	def StartAddress(self, value):
		self._set_attribute('startAddress', value)

	@property
	def SupportSmrGeneration(self):
		"""It supports smr generation

		Returns:
			bool
		"""
		return self._get_attribute('supportSmrGeneration')
	@SupportSmrGeneration.setter
	def SupportSmrGeneration(self, value):
		self._set_attribute('supportSmrGeneration', value)

	@property
	def Ttl(self):
		"""It gives details about the ttl

		Returns:
			number
		"""
		return self._get_attribute('ttl')
	@Ttl.setter
	def Ttl(self, value):
		self._set_attribute('ttl', value)

	@property
	def UseAllInterfaceAddressesAsLocator(self):
		"""If True, it uses all interface address as locator

		Returns:
			bool
		"""
		return self._get_attribute('useAllInterfaceAddressesAsLocator')
	@UseAllInterfaceAddressesAsLocator.setter
	def UseAllInterfaceAddressesAsLocator(self, value):
		self._set_attribute('useAllInterfaceAddressesAsLocator', value)

	def update(self, Count=None, EnableProxyMapReplyBit=None, EnableWantMapNotifyBit=None, Enabled=None, Family=None, MaxRecordPerMapRegisterPacket=None, PeriodicRefreshInterval=None, PrefixLength=None, QuickRegistrationPeriod=None, RefreshIntervalInQuickRegistrationPeriod=None, StartAddress=None, SupportSmrGeneration=None, Ttl=None, UseAllInterfaceAddressesAsLocator=None):
		"""Updates a child instance of localEidRange on the server.

		Args:
			Count (number): It gives details about the count
			EnableProxyMapReplyBit (bool): If true, it enables the proxy map reply bit
			EnableWantMapNotifyBit (str(always|duringQuickRegistration|never)): If true, it enables the Want map Notify bit
			Enabled (bool): If true, it enables the protocol
			Family (str(ipv4|ipv6)): It gives details about the family
			MaxRecordPerMapRegisterPacket (number): It gives details about the maximum record per map register packet
			PeriodicRefreshInterval (number): It gives details about the periodic refresh interval
			PrefixLength (number): it gives details about the prefix length
			QuickRegistrationPeriod (number): it gives details about the quick registration period
			RefreshIntervalInQuickRegistrationPeriod (number): It refreshs the interval in quick registration periods
			StartAddress (str): It gives details about the start address
			SupportSmrGeneration (bool): It supports smr generation
			Ttl (number): It gives details about the ttl
			UseAllInterfaceAddressesAsLocator (bool): If True, it uses all interface address as locator

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, Count=None, EnableProxyMapReplyBit=None, EnableWantMapNotifyBit=None, Enabled=None, Family=None, MaxRecordPerMapRegisterPacket=None, PeriodicRefreshInterval=None, PrefixLength=None, QuickRegistrationPeriod=None, RefreshIntervalInQuickRegistrationPeriod=None, StartAddress=None, SupportSmrGeneration=None, Ttl=None, UseAllInterfaceAddressesAsLocator=None):
		"""Adds a new localEidRange node on the server and retrieves it in this instance.

		Args:
			Count (number): It gives details about the count
			EnableProxyMapReplyBit (bool): If true, it enables the proxy map reply bit
			EnableWantMapNotifyBit (str(always|duringQuickRegistration|never)): If true, it enables the Want map Notify bit
			Enabled (bool): If true, it enables the protocol
			Family (str(ipv4|ipv6)): It gives details about the family
			MaxRecordPerMapRegisterPacket (number): It gives details about the maximum record per map register packet
			PeriodicRefreshInterval (number): It gives details about the periodic refresh interval
			PrefixLength (number): it gives details about the prefix length
			QuickRegistrationPeriod (number): it gives details about the quick registration period
			RefreshIntervalInQuickRegistrationPeriod (number): It refreshs the interval in quick registration periods
			StartAddress (str): It gives details about the start address
			SupportSmrGeneration (bool): It supports smr generation
			Ttl (number): It gives details about the ttl
			UseAllInterfaceAddressesAsLocator (bool): If True, it uses all interface address as locator

		Returns:
			self: This instance with all currently retrieved localEidRange data using find and the newly added localEidRange data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the localEidRange data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, Count=None, EnableProxyMapReplyBit=None, EnableWantMapNotifyBit=None, Enabled=None, Family=None, MaxRecordPerMapRegisterPacket=None, PeriodicRefreshInterval=None, PrefixLength=None, QuickRegistrationPeriod=None, RefreshIntervalInQuickRegistrationPeriod=None, StartAddress=None, SupportSmrGeneration=None, Ttl=None, UseAllInterfaceAddressesAsLocator=None):
		"""Finds and retrieves localEidRange data from the server.

		All named parameters support regex and can be used to selectively retrieve localEidRange data from the server.
		By default the find method takes no parameters and will retrieve all localEidRange data from the server.

		Args:
			Count (number): It gives details about the count
			EnableProxyMapReplyBit (bool): If true, it enables the proxy map reply bit
			EnableWantMapNotifyBit (str(always|duringQuickRegistration|never)): If true, it enables the Want map Notify bit
			Enabled (bool): If true, it enables the protocol
			Family (str(ipv4|ipv6)): It gives details about the family
			MaxRecordPerMapRegisterPacket (number): It gives details about the maximum record per map register packet
			PeriodicRefreshInterval (number): It gives details about the periodic refresh interval
			PrefixLength (number): it gives details about the prefix length
			QuickRegistrationPeriod (number): it gives details about the quick registration period
			RefreshIntervalInQuickRegistrationPeriod (number): It refreshs the interval in quick registration periods
			StartAddress (str): It gives details about the start address
			SupportSmrGeneration (bool): It supports smr generation
			Ttl (number): It gives details about the ttl
			UseAllInterfaceAddressesAsLocator (bool): If True, it uses all interface address as locator

		Returns:
			self: This instance with matching localEidRange data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of localEidRange data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the localEidRange data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class Bfdv6Session(Base):
	"""The Bfdv6Session class encapsulates a required bfdv6Session node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the Bfdv6Session property from a parent instance.
	The internal properties list will contain one and only one set of properties which is populated when the property is accessed.
	"""

	_SDM_NAME = 'bfdv6Session'

	def __init__(self, parent):
		super(Bfdv6Session, self).__init__(parent)

	@property
	def Active(self):
		"""Activate/Deactivate Configuration

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('active')

	@property
	def Count(self):
		"""Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group

		Returns:
			number
		"""
		return self._get_attribute('count')

	@property
	def DescriptiveName(self):
		"""Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but maybe offers more context

		Returns:
			str
		"""
		return self._get_attribute('descriptiveName')

	@property
	def EnableAutoChooseSourceIp(self):
		"""Selecting this check box enables the ability to configure the source IP address IP of BFD Session

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('enableAutoChooseSourceIp')

	@property
	def EnableOVSDBCommunication(self):
		"""Selecting this check box enables the ability to communicate the remote IP and MAC address of BFD Session

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('enableOVSDBCommunication')

	@property
	def EnableRemoteDiscriminatorLearned(self):
		"""Selecting this check box enables the ability to configure the remote discriminator for BFD Session

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('enableRemoteDiscriminatorLearned')

	@property
	def LearnedRemoteMac(self):
		"""The learned remote MAC address from controller

		Returns:
			list(str)
		"""
		return self._get_attribute('learnedRemoteMac')

	@property
	def LocalRouterId(self):
		"""The BFD Router ID value, in IPv4 format.

		Returns:
			list(str)
		"""
		return self._get_attribute('localRouterId')

	@property
	def MyDiscriminator(self):
		"""The discriminator used locally for the BFD session

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('myDiscriminator')

	@property
	def Name(self):
		"""Name of NGPF element, guaranteed to be unique in Scenario

		Returns:
			str
		"""
		return self._get_attribute('name')
	@Name.setter
	def Name(self, value):
		self._set_attribute('name', value)

	@property
	def RemoteDiscriminator(self):
		"""The remote discriminator used by the peer BFD for session

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('remoteDiscriminator')

	@property
	def RemoteIp6(self):
		"""The remote IP address used in BFD session

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('remoteIp6')

	@property
	def RemoteMac(self):
		"""Remote MAC Address of Peer

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('remoteMac')

	@property
	def SessionInfo(self):
		"""Logs additional information about the Session state

		Returns:
			list(str[adminDown|awaitingIp|down|init|maxState|sessDeleted|unknownState|up])
		"""
		return self._get_attribute('sessionInfo')

	@property
	def SessionType(self):
		"""Session Type used in BFD session. One of: Single Hop, Multi Hops

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('sessionType')

	@property
	def SourceIp6(self):
		"""The source IP address used in BFD session

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('sourceIp6')

	@property
	def Vni(self):
		"""Corresponding VXLAN Protocol VNI.

		Returns:
			list(number)
		"""
		return self._get_attribute('vni')

	def update(self, Name=None):
		"""Updates a child instance of bfdv6Session on the server.

		This method has some named parameters with a type: obj (Multivalue).
		The Multivalue class has the associated documentation that details the possible values for those named parameters.

		Args:
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def get_device_ids(self, PortNames=None, Active=None, EnableAutoChooseSourceIp=None, EnableOVSDBCommunication=None, EnableRemoteDiscriminatorLearned=None, MyDiscriminator=None, RemoteDiscriminator=None, RemoteIp6=None, RemoteMac=None, SessionType=None, SourceIp6=None):
		"""Base class infrastructure that gets a list of bfdv6Session device ids encapsulated by this object.

		Use the optional regex parameters in the method to refine the list of device ids encapsulated by this object.

		Args:
			PortNames (str): optional regex of port names
			Active (str): optional regex of active
			EnableAutoChooseSourceIp (str): optional regex of enableAutoChooseSourceIp
			EnableOVSDBCommunication (str): optional regex of enableOVSDBCommunication
			EnableRemoteDiscriminatorLearned (str): optional regex of enableRemoteDiscriminatorLearned
			MyDiscriminator (str): optional regex of myDiscriminator
			RemoteDiscriminator (str): optional regex of remoteDiscriminator
			RemoteIp6 (str): optional regex of remoteIp6
			RemoteMac (str): optional regex of remoteMac
			SessionType (str): optional regex of sessionType
			SourceIp6 (str): optional regex of sourceIp6

		Returns:
			list(int): A list of device ids that meets the regex criteria provided in the method parameters

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._get_ngpf_device_ids(locals())

	def FetchAndUpdateConfigFromCloud(self, *args, **kwargs):
		"""Executes the fetchAndUpdateConfigFromCloud operation on the server.

		fetchAndUpdateConfigFromCloud(Mode:string)
			Args:
				args[0] is Mode (str): 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('fetchAndUpdateConfigFromCloud', payload=payload, response_object=None)

	def Start(self, *args, **kwargs):
		"""Executes the start operation on the server.

		Activate Session

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		start()

		start(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		start(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		start(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin. An empty list indicates all instances in the plugin.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('start', payload=payload, response_object=None)

	def Stop(self, *args, **kwargs):
		"""Executes the stop operation on the server.

		Deactivate Session

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		stop()

		stop(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		stop(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		stop(Arg2:list)list
			Args:
				args[0] is Arg2 (list(number)): List of indices into the protocol plugin. An empty list indicates all instances in the plugin.

			Returns:
				list(str): ID to associate each async action invocation

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('stop', payload=payload, response_object=None)
